@@ -74,7 +74,8 @@ def test_run_full_case(tmpdir, case_dir, parallel):
                  'automodsumm_writereprocessed': True})
 
     if os.path.basename(case_dir) in ('mixed_toplevel',
-                                      'mixed_toplevel_all_objects'):
+                                      'mixed_toplevel_all_objects',
+                                      'allowed_names'):
         conf['extensions'].append('sphinx_automodapi.smart_resolver')
 
     start_dir = os.path.abspath('.')
